@@ -88,6 +88,7 @@ import inspect
 import json
 import os
 import sys
+import traceback
 import types
 
 from aiohttp import web
@@ -164,7 +165,8 @@ class WebApplication:
             if new_lease_time > 0:
                 await asyncio.sleep(new_lease_time)
             if hasattr(cls.instances[obj_id], '__aexit__'):
-                await cls.instances[obj_id].__aexit__(None, None, None)
+                with suppress(Exception):
+                    await cls.instances[obj_id].__aexit__(None, None, None)
             del cls.instances[obj_id]
             del cls.expiry[obj_id]
 
@@ -320,7 +322,7 @@ class WebApplication:
         """
         if route in WebApplication.routes_post or route in WebApplication.routes_get:
             existing = WebApplication.callables_get.get(route) or WebApplication.callables_post.get(route)
-            raise WebApplication.DuplicateRoute(f"Route '{route}' associated with {api.module}.{func.name}"
+            raise WebApplication.DuplicateRoute(f"Route '{route}' associated with {api.module}.{api._func.__name__}"
                                                 f" already exists here {existing.module}.{existing.name} ")
         WebApplication.routes_post[route] = async_method
         WebApplication.callables_post[route] = api
@@ -418,14 +420,14 @@ class WebApplication:
             @staticmethod
             async def _create(*args, **kargs) -> str:
                 if '__uuid' in kargs:
-                    del kargs['__uuid']
                     self_id = kargs['__uuid']
+                    del kargs['__uuid']
                     if self_id in cls.ObjectRepo.instances:
                         raise HTTPException(404, f"UUid {self_id} already in use. uuid's must be unique")
                 instance = clazz_(*args, **kargs)
                 if hasattr(clazz_, '__aenter__'):
                     await instance.__aenter__()
-                self_id = kargs.get('__uuid') or str(instance).split(' ')[-1][:-1]
+                self_id = self_id or str(instance).split(' ')[-1][:-1]
                 cls.ObjectRepo.instances[self_id] = instance
                 cls.ObjectRepo.expiry[self_id] = asyncio.create_task(cls.ObjectRepo.expire_obj(
                     self_id, cls.ObjectRepo.DEFAULT_OBJECT_EXPIRATION))
@@ -445,18 +447,18 @@ class WebApplication:
             # noinspection PyProtectedMember
             cls._func_wrapper(clazz_._create, is_instance_method=False, method=RestMethod.GET, content_type="text/plain")
 
-            async def _expire(self, new_lease_time: int = cls.ObjectRepo.DEFAULT_OBJECT_EXPIRATION) -> None:
+            async def _expire(self, new_lease_time: int = cls.ObjectRepo.DEFAULT_OBJECT_EXPIRATION,
+                              _uuid: Optional[str] = None) -> None:
                 """
                 Release/close an instance on the server that was created through invocation of _create for the
                 associated resource
                 """
-                self_id = str(self).split(' ')[-1][:-1]
+                self_id = _uuid or str(self).split(' ')[-1][:-1]
                 if self_id not in cls.ObjectRepo.instances:
-                    raise HTTPException(code=404, msg=f"No such object with id {self._id}")
+                    raise HTTPException(code=404, msg=f"No such object with id {self_id}")
                 cls.ObjectRepo.expiry[self_id].cancel()
                 if cls.ObjectRepo.instances and new_lease_time <= 0:
-                    del cls.ObjectRepo.instances[self_id]
-                    del cls.ObjectRepo.expiry[self_id]
+                    await cls.ObjectRepo.expire_obj(self_id, 0)
                 else:
                     cls.ObjectRepo.expiry[self_id] = asyncio.create_task(
                         cls.ObjectRepo.expire_obj(self_id, new_lease_time))
@@ -624,11 +626,11 @@ class WebApplication:
                 return Response(status=200, body=result if result is not None else b"Success",
                                 content_type=content_type)
         except TypeError as e:
-            return Response(status=400, text=f"Improperly formatted query: {str(e)}")
+            return Response(status=400, text=f"Improperly formatted query: {str(e)}\n{traceback.format_exc()}")
         except HTTPException as e:
-            return Response(status=e.status_code, text=str(e))
+            return Response(status=e.status_code, text=f"{e}: \n{traceback.format_exc()}")
         except Exception as e:
-            return Response(status=500, text=str(e))
+            return Response(status=500, text=f"{e}: \n{traceback.format_exc()}")
         finally:
             # noinspection PyUnresolvedReferences,PyProtectedMember
             del cls._context[sys._getframe(0)]
